var svgNS = "http://www.w3.org/2000/svg";
var vertices = []; //pole uzlu
var edges = []; // pole hran

function drawGraph() {
    
    clearGraph()
    
    var data = document.getElementById("vstupni").value;
    
    var vals = data.split(".");
    
    var nodeCount = parseInt( vals[0].substring(1) );
    
    var svgSize = document.getElementById("svgRoot").getBoundingClientRect();
    
    var sx = svgSize.width/2;
    var sy = svgSize.height/2;
    
    var radius = Math.min(sx, sy) - 30;
    
    
    //vykresleni uzlu
    for (var i = 0; i < nodeCount; i++) {
        var newNode = document.createElementNS(svgNS, "circle");
        newNode.setAttribute("r", 10); // polomer kruhu
        
        var phi = Math.PI*2/nodeCount*i;
        var cx = sx + radius*Math.cos(phi);
        var cy = sy + radius*Math.sin(phi);
        
        newNode.setAttribute("cx", cx);
        newNode.setAttribute("cy", cy);
        
        newNode.onclick = nodeClickHandler;
        
        
        document.getElementById("vertices").appendChild(newNode);
        vertices.push(newNode);
    }
    
    //vykresleni hran
    for (var i =1; i < vals.length; i++) {
        var index1 = vals[i].charCodeAt(0) - 97; //ciselne indexy uzlu
        var index2 = vals[i].charCodeAt(1) - 97;
        
        var newLine = document.createElementNS(svgNS, "line");
        newLine.setAttribute("x1", vertices[index1].getAttribute("cx") );
        newLine.setAttribute("y1", vertices[index1].getAttribute("cy") );
        
        newLine.setAttribute("x2", vertices[index2].getAttribute("cx") );
        newLine.setAttribute("y2", vertices[index2].getAttribute("cy") );
        
        newLine.onclick = lineClickHandler;        
        
        document.getElementById("edges").appendChild(newLine);
                
        var edge =  [ Math.min(index1, index2), Math.max(index1, index2), newLine]  
        edges.push(edge)
    }
}

function lineClickHandler(evt) {
    var line = evt.currentTarget; //urceni zdroje klikani
    if (line.nodeName != "line") return;
    
    removeEdge(line);
}
function removeEdge(edge) {
   for (var i = 0; i < edges.length; i++) {
        if (edges[i][2] == edge ) {
           edges.splice(i, 1); // vyjmuti prvku s indexem i z pole;
           document.getElementById("edges").removeChild(edge); //odstraneni cary z SVG 
            return;
        }
   }
}

var actVertex = null;

function nodeClickHandler(evt) {
    var node = evt.currentTarget;
    if (node.nodeName != "circle") return;
    
    if (actVertex == null) {
        actVertex = node;
        node.setAttribute("class", "selected");
        return;
    }
    
    else {
        if (actVertex == node) { //znovu se kliklo na vybrany uzel
            node.setAttribute("class", "");
            
            actVertex = null;
            return;
        }
        
        else {
            addEdge( node, actVertex );
            actVertex = null;
        }
    }
} 

function addEdge(node1, node2) {
    var index1 = 0, index2 = 0;
    
    for (var i = 0; i < vertices.length; i++) { //zjisteni indexu uzlu
       if (vertices[i] == node1) {
           index1 = i;
       }
       if (vertices[i] == node2) {
           index2 = i;
       }
    }
    
    for (var i = 0; i < edges.length; i++) { // kontrola existence hrany 
        if ( edges[i][0] == index1 && edges[i][1] == index2 ||
           edges[i][0] == index2 && edges[i][1] == index1
           ) {
            return;
        }
    }
    
    var newLine = document.createElementNS(svgNS, "line");
    newLine.setAttribute("x1", vertices[index1].getAttribute("cx") );
    newLine.setAttribute("y1", vertices[index1].getAttribute("cy") );
    
    newLine.setAttribute("x2", vertices[index2].getAttribute("cx") );
    newLine.setAttribute("y2", vertices[index2].getAttribute("cy") );
    
    newLine.onclick = lineClickHandler;        
    
    document.getElementById("edges").appendChild(newLine);
            
    var edge =  [ Math.min(index1, index2), Math.max(index1, index2), newLine]  
    edges.push(edge);
}

function clearGraph() {
    //vymazani uzlu
    for (var i = 0; i < vertices.length; i++) {
        vertices[i].parentNode.removeChild(vertices[i]);
    }
    vertices = [];
    
    //vymazani hran
    for (var i = 0; i < edges.length; i++) {
        edges[i][2].parentNode.removeChild(edges[i][2]);
    }
    edges = [];    
    
}

function getGraphData() {
    var vystup = "G";
    
    vystup += vertices.length;
    
    edges.sort(edgeSorter); //serazeni hran podle velikosti indexu
    
    for (var i = 0; i < edges.length; i++) {
        vystup += "." + String.fromCharCode(97 + edges[i][0]) + String.fromCharCode(97 + edges[i][1]); 
    }
    
    document.getElementById("vystupni").value = vystup;
}
    
function edgeSorter(edge1, edge2) {
    if (edge1[0] > edge2[0]) return 1;
    if (edge1[0] < edge2[0]) return -1;
    
    if (edge1[0] == edge2[0]) {
        if (edge1[1] > edge2[1]) return 1;
        if (edge1[1] < edge2[1]) return -1;
        
        return 0;
    }
}    
    
    
    
    
    
    
    
    
    